#!/usr/bin/env node
"use strict";

var _get = _interopRequireDefault(require("lodash/get"));

var _commander = _interopRequireDefault(require("commander"));

var _ = _interopRequireDefault(require(".."));

var _helpers = require("../helpers");

var _package = _interopRequireDefault(require("../../package.json"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander.default.version(_package.default.version).description(_package.default.description).usage('[options] <source directory>').option('-w, --watch', 'Watch files for changes').option('--root <directory>', 'Root directory for babel. This is where presets are resolved from').option('--ignored <list>', 'Ignored files and directories that match the given globs', value => value.split(',').map(item => item.trim()).filter(Boolean)).option('--write-flow-sources', 'Write .flow files that are symlinked to source files. Helps with monorepos in some cases').option('--disable-cache', 'Force recompile all files ignoring cache').option('--keep-extra-files', 'Do NOT delete extra files in the output directory').option('-o, --output-directory <directory>', 'Output directory to write transpiled files to').option('-x, --execute <entryFile>', 'Relative path of file to execute (only supported in watcher mode)').option('--execute-delay <delay>', 'Delay in ms to in between restarts of executed file (defaults to 1000ms)', value => parseInt(value, 10) || 1000).option('--typescript', 'Enables typescript support by processing .ts and .tsx files').parse(process.argv);

if (_commander.default.args.length !== 1) {
  _commander.default.outputHelp();

  process.exit(1);
}

if (typeof _commander.default.outputDirectory === 'undefined') {
  console.log('ERROR: You must specify output directory');

  _commander.default.outputHelp();

  process.exit(1);
}

const config = {
  root: (0, _get.default)(_commander.default, 'root', process.cwd()),
  watch: (0, _get.default)(_commander.default, 'watch', false),
  ignored: (0, _get.default)(_commander.default, 'ignored', []),
  disableCache: (0, _get.default)(_commander.default, 'disableCache', false),
  writeFlowSources: (0, _get.default)(_commander.default, 'writeFlowSources', false),
  keepExtraFiles: (0, _get.default)(_commander.default, 'keepExtraFiles', false),
  sourceDirectory: _commander.default.args[0],
  outputDirectory: _commander.default.outputDirectory,
  typescript: _commander.default.typescript,
  execute: (0, _get.default)(_commander.default, 'execute', ''),
  executeDelay: (0, _get.default)(_commander.default, 'executeDelay', 250)
};

if (!config.watch && config.execute) {
  console.error('ERROR: --execute is not supported without --watch');
  process.exit(1);
}

(0, _.default)(config).catch(error => {
  (0, _helpers.logError)(error);
  process.exit(1);
});