"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSha1 = getSha1;
exports.getCacheDB = getCacheDB;
exports.logError = logError;
exports.getBabelTransformFile = getBabelTransformFile;
exports.CLIError = void 0;

var _os = _interopRequireDefault(require("os"));

var _lowdb = _interopRequireDefault(require("lowdb"));

var _pify = _interopRequireDefault(require("pify"));

var _path = _interopRequireDefault(require("path"));

var _crypto = _interopRequireDefault(require("crypto"));

var _makeDir = _interopRequireDefault(require("make-dir"));

var _debounce = _interopRequireDefault(require("lodash/debounce"));

var _resolveFrom = _interopRequireDefault(require("resolve-from"));

var _FileAsync = _interopRequireDefault(require("lowdb/adapters/FileAsync"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

class CLIError extends Error {}

exports.CLIError = CLIError;

function getSha1(contents) {
  const hash = _crypto.default.createHash('sha1');

  hash.update(contents);
  return hash.digest('hex');
}

function getCacheDB(_x, _x2) {
  return _getCacheDB.apply(this, arguments);
}

function _getCacheDB() {
  _getCacheDB = _asyncToGenerator(function* (projectPath, loadState) {
    const configPath = _path.default.join(_os.default.homedir(), '.sb-babel-cli', `cache-timestamps-${getSha1(projectPath)}`);

    yield (0, _makeDir.default)(_path.default.dirname(configPath));
    const adapter = new _FileAsync.default(configPath, {
      serialize: JSON.stringify
    });
    adapter.write = (0, _debounce.default)(adapter.write, 1000);
    const db = yield (0, _lowdb.default)(adapter);

    if (!loadState) {
      yield db.setState({});
    }

    return db;
  });
  return _getCacheDB.apply(this, arguments);
}

function logError(error) {
  if (error instanceof CLIError) {
    console.error('ERROR', error.message);
  } else {
    console.error(error);
  }
}

let transformFileCached;

function getBabelTransformFile(projectPath) {
  if (!transformFileCached) {
    let resolved;

    try {
      resolved = (0, _resolveFrom.default)(projectPath, '@babel/core');
    } catch (_) {
      /* No Op */
    }

    if (!resolved) {
      throw new CLIError('Unable to find @babel/core in your project');
    } // eslint-disable-next-line global-require,import/no-dynamic-require


    const babelCore = require(resolved);

    transformFileCached = (0, _pify.default)(babelCore.transformFile);
  }

  return transformFileCached;
}